@@ -317,8 +317,8 @@ confirm_overwrite_existing_file (GFile *uri, int *overwrite_mode, goffset info_s
   play_preview = egg_play_preview_new_with_uri (filename);
   g_object_set (play_preview,
                 "halign", GTK_ALIGN_FILL,
-                "margin-left", 30,
-                "margin-right", 30, NULL);
+                "margin-start", 30,
+                "margin-end", 30, NULL);
   gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), play_preview);
   g_free (filename);
 
